@@ -75,6 +75,10 @@ class BoltztrapRunner():
                 type of boltztrap usage by default BOLTZ to compute transport coefficients
                 but you can have also "FERMI" to compute fermi surface or more correctly to
                 get certain bands interpolated
+            soc:
+                results from spin-orbit coupling (soc) computations give typically non-polarized (no spin up or down)
+                results but 1 electron occupations. If the band structure comes from a soc computation, you should set
+                soc to True (default False)
     """
 
     @requires(which('x_trans'),
@@ -85,7 +89,7 @@ class BoltztrapRunner():
               "Bolztrap accordingly. Then add x_trans to your path")
 
     def __init__(self, bs, nelec, dos_type="HISTO", energy_grid=0.005,
-                 lpfac=10, type="BOLTZ", band_nb=None):
+                 lpfac=10, type="BOLTZ", band_nb=None, tauref=0, tauexp=0, tauen=0, soc=False):
         self.lpfac = lpfac
         self._bs = bs
         self._nelec = nelec
@@ -94,6 +98,10 @@ class BoltztrapRunner():
         self.error = []
         self.type = type
         self.band_nb = band_nb
+        self.tauref=tauref
+        self.tauexp=tauexp
+        self.tauen=tauen
+        self.soc=soc
 
     def _make_energy_file(self, file_name):
         with open(file_name, 'w') as f:
@@ -135,7 +143,7 @@ class BoltztrapRunner():
     def _make_def_file(self, def_file_name):
         with open(def_file_name,'w') as f:
             so = ""
-            if self._bs.is_spin_polarized:
+            if self._bs.is_spin_polarized or self.soc:
                 so = "so"
             f.write("5, 'boltztrap.intrans',      'old',    'formatted',0\n"+
                     "6,'boltztrap.outputtrans',      'unknown',    'formatted',0\n"+
@@ -198,7 +206,8 @@ class BoltztrapRunner():
                         i += 1
 
     def _make_intrans_file(self, file_name,
-                           doping=[1e15, 1e16, 1e17, 1e18, 1e19, 1e20], type="BOLTZ", band_nb=None):
+                           doping=[1e15, 1e16, 1e17, 1e18, 1e19, 1e20], type="BOLTZ", band_nb=None,
+                           tauref=0, tauexp=0, tauen=0):
         if type == "BOLTZ":
             with open(file_name, 'w') as fout:
                 fout.write("GENE          # use generic interface\n")
@@ -214,7 +223,7 @@ class BoltztrapRunner():
                 fout.write("800. 100.                  # Tmax, temperature grid\n")
                 fout.write("-1.  # energyrange of bands given DOS output sig_xxx and dos_xxx (xxx is band number)\n")
                 fout.write(self.dos_type+"\n")
-                fout.write("0 0 0 0 0\n")
+                fout.write(str(tauref)+" "+str(tauexp)+" "+str(tauen)+" 0 0 0\n")
                 fout.write(str(2*len(doping))+"\n")
                 for d in doping:
                     fout.write(str(d)+"\n")
@@ -234,7 +243,7 @@ class BoltztrapRunner():
                 fout.write(str(band_nb+1))
 
     def _make_all_files(self, path):
-        if self._bs.is_spin_polarized:
+        if self._bs.is_spin_polarized or self.soc:
             self._make_energy_file(os.path.join(path, "boltztrap.energyso"))
         else:
             self._make_energy_file(os.path.join(path, "boltztrap.energy"))
@@ -263,7 +272,7 @@ class BoltztrapRunner():
         os.chdir(path_dir)
 
         self._make_all_files(path_dir)
-        if self._bs.is_spin_polarized:
+        if self._bs.is_spin_polarized or self.soc:
             p = subprocess.Popen(["x_trans", "BoltzTraP", "-so"],
                                  stdout=subprocess.PIPE,
                                  stdin=subprocess.PIPE, stderr=subprocess.PIPE)
