@@ -16,9 +16,12 @@ __date__ = "Mar 19, 2012"
 
 
 import os
-import ConfigParser
+
 from collections import defaultdict
 
+from monty.design_patterns import cached_class
+from monty.serialization import loadfn
+
 from pymatgen.io.vaspio_set import MITVaspInputSet, MPVaspInputSet
 from pymatgen.core.periodic_table import Element
 from pymatgen.analysis.structure_analyzer import oxide_type
@@ -93,24 +96,16 @@ class PotcarCorrection(Correction):
     'PAW_PBE O 08Apr2002'].
 
     Args:
-        name: Name of settings to use. Current valid settings are MP or
-            MIT, which is the relevant settings based on the MP or MIT
-            VaspInputSets.
+        input_set: InputSet object used to generate the runs (used to check
+            for correct potcar symbols)
 
     Raises:
         ValueError if entry do not contain "potcar_symbols" key.
         CombatibilityError if wrong potcar symbols
     """
-    def __init__(self, name):
-        if name == "MP":
-            input_set = MPVaspInputSet()
-        elif name == "MIT":
-            input_set = MITVaspInputSet()
-        else:
-            raise ValueError("Only MIT and MP POTCAR corrections are "
-                             "supported currently.")
+    def __init__(self, input_set):
         self.valid_potcars = set(input_set.potcar_settings.values())
-        self.name = name
+        self.input_set = input_set
 
     def get_correction(self, entry):
         try:
@@ -126,33 +121,25 @@ class PotcarCorrection(Correction):
         return 0
 
     def __str__(self):
-        return "{} Potcar Correction".format(self.name)
+        return "{} Potcar Correction".format(self.input_set.name)
 
 
+@cached_class
 class GasCorrection(Correction):
     """
     Correct gas energies to obtain the right formation energies. Note that
     this depends on calculations being run within the same input set.
 
     Args:
-        name: Name of settings to use. Current valid settings are MP or
-            MIT, which is the relevant settings based on the MP or MIT
-            VaspInputSets.
-        correct_peroxide: Specify whether peroxide/superoxide/ozonide 
-            corrections are to be applied or not. 
+        config_file: Path to the selected compatibility.yaml config file.
+        correct_peroxide: Specify whether peroxide/superoxide/ozonide
+            corrections are to be applied or not.
     """
-    def __init__(self, name, correct_peroxide=True):
-        module_dir = os.path.dirname(os.path.abspath(__file__))
-        config = ConfigParser.SafeConfigParser()
-        config.optionxform = str
-        config.readfp(open(os.path.join(module_dir, "Compatibility.cfg")))
-        cpd_energies = dict(
-            config.items("{}CompoundEnergies".format(name)))
-        self.cpd_energies = {k: float(v) for k, v in cpd_energies.items()}
-        self.oxide_correction = {
-            k: float(v) for k, v
-            in config.items("{}OxideCorrection".format(name))}
-        self.name = name
+    def __init__(self, config_file, correct_peroxide=True):
+        c = loadfn(config_file)
+        self.cpd_energies = c['Advanced']['CompoundEnergies']
+        self.oxide_correction = c['OxideCorrections']
+        self.name = c['Name']
         self.correct_peroxide = correct_peroxide
 
     def get_correction(self, entry):
@@ -175,7 +162,7 @@ class GasCorrection(Correction):
                     if entry.data["oxide_type"] == "hydroxide":
                         ox_corr = self.oxide_correction["oxide"]
                         correction += ox_corr * comp["O"]
-    
+
                 elif hasattr(entry, "structure"):
                     ox_type, nbonds = oxide_type(entry.structure, 1.05,
                                                  return_nbonds=True)
@@ -194,7 +181,8 @@ class GasCorrection(Correction):
                     elif rform in UCorrection.ozonides:
                         correction += self.oxide_correction["ozonide"] * \
                             comp["O"]
-                    elif Element("O") in comp.elements and len(comp.elements) > 1:
+                    elif Element("O") in comp.elements and len(comp.elements)\
+                            > 1:
                         correction += self.oxide_correction['oxide'] * comp["O"]
         else:
             correction += self.oxide_correction['oxide'] * comp["O"]
@@ -205,24 +193,19 @@ class GasCorrection(Correction):
         return "{} Gas Correction".format(self.name)
 
 
+@cached_class
 class AqueousCorrection(Correction):
     """
     This class implements aqueous phase compound corrections for elements
     and H2O.
 
     Args:
-        name: The name of the input set to use. Can be either MP or MIT.
+        config_file: Path to the selected compatibility.yaml config file.
     """
-    def __init__(self, name):
-        module_dir = os.path.dirname(os.path.abspath(__file__))
-        config = ConfigParser.SafeConfigParser()
-        config.optionxform = str
-        config.readfp(open(os.path.join(module_dir,
-                                        "Compatibility.cfg")))
-        cpd_energies = dict(
-            config.items("{}AqueousCompoundEnergies".format(name)))
-        self.cpd_energies = {k: float(v) for k, v in cpd_energies.items()}
-        self.name = name
+    def __init__(self, config_file):
+        c = loadfn(config_file)
+        self.cpd_energies = c['AqueousCompoundEnergies']
+        self.name = c["Name"]
 
     def get_correction(self, entry):
         comp = entry.composition
@@ -243,6 +226,7 @@ class AqueousCorrection(Correction):
         return "{} Aqueous Correction".format(self.name)
 
 
+@cached_class
 class UCorrection(Correction):
     """
     This class implements the GGA/GGA+U mixing scheme, which allows mixing of
@@ -258,9 +242,8 @@ class UCorrection(Correction):
     these fields populated.
 
     Args:
-        name: Name of settings to use. Current valid settings are MP or
-            MIT, which is the relevant settings based on the MP or MIT
-            VaspInputSets.
+        config_file: Path to the selected compatibility.yaml config file.
+        input_set: InputSet object (to check for the +U settings)
         compat_type: Two options, GGA or Advanced.  GGA means all GGA+U
             entries are excluded.  Advanced means mixing scheme is
             implemented to make entries compatible with each other,
@@ -274,33 +257,22 @@ class UCorrection(Correction):
     common_superoxides = ["LiO2", "NaO2", "KO2", "RbO2", "CsO2"]
     ozonides = ["LiO3", "NaO3", "KO3", "NaO5"]
 
-    def __init__(self, name, compat_type):
-        module_dir = os.path.dirname(os.path.abspath(__file__))
-        config = ConfigParser.SafeConfigParser()
-        config.optionxform = str
-        config.readfp(open(os.path.join(module_dir, "Compatibility.cfg")))
-        if name == "MP":
-            self.input_set = MPVaspInputSet()
-        elif name == "MIT":
-            self.input_set = MITVaspInputSet()
+    def __init__(self, config_file, input_set, compat_type):
+        if compat_type not in ['GGA', 'Advanced']:
+            raise CompatibilityError("Invalid compat_type {}"
+                                     .format(compat_type))
+
+        c = loadfn(config_file)
+
+        self.input_set = input_set
+        if compat_type == 'Advanced':
+            self.u_settings = self.input_set.incar_settings["LDAUU"]
+            self.u_corrections = c["Advanced"]["UCorrections"]
         else:
-            raise ValueError("Invalid input set name {}".format(name))
-
-        u_corrections = {}
-        for el in self.input_set.incar_settings["LDAUU"].keys():
-            sect_name = "{}{}UCorrections{}".format(name, compat_type, el)
-            if sect_name in config.sections():
-                corr = dict(config.items(sect_name))
-                u_corrections[el] = {k: float(v) for k, v in corr.items()}
-
-        self.u_corrections = u_corrections
-        self.u_settings = self.input_set.incar_settings["LDAUU"]
-
-        if compat_type == "GGA":
-            self.u_corrections = {}
             self.u_settings = {}
+            self.u_corrections = {}
 
-        self.name = name
+        self.name = c["Name"]
         self.compat_type = compat_type
 
     def get_correction(self, entry):
@@ -315,7 +287,6 @@ class UCorrection(Correction):
                           key=lambda el: el.X)
         most_electroneg = elements[-1].symbol
         correction = 0
-
         ucorr = self.u_corrections.get(most_electroneg, {})
         usettings = self.u_settings.get(most_electroneg, {})
 
@@ -398,6 +369,7 @@ class Compatibility(object):
         return filter(None, map(self.process_entry, entries))
 
 
+@cached_class
 class MaterialsProjectCompatibility(Compatibility):
     """
     This class implements the GGA/GGA+U mixing scheme, which allows mixing of
@@ -414,17 +386,21 @@ class MaterialsProjectCompatibility(Compatibility):
             equivalent GGA entries excluded. For example, Fe oxides should
             have a U value under the Advanced scheme. A GGA Fe oxide run
             will therefore be excluded under the scheme.
-        correct_peroxide: Specify whether peroxide/superoxide/ozonide 
-            corrections are to be applied or not. 
+        correct_peroxide: Specify whether peroxide/superoxide/ozonide
+            corrections are to be applied or not.
     """
 
     def __init__(self, compat_type="Advanced", correct_peroxide=True):
-        name = "MP"
+        module_dir = os.path.dirname(os.path.abspath(__file__))
+        fp = os.path.join(module_dir, "MPCompatibility.yaml")
+        i_s = MPVaspInputSet()
         Compatibility.__init__(
-            self, [PotcarCorrection(name), GasCorrection(name, correct_peroxide=correct_peroxide),
-                   UCorrection(name, compat_type)])
+            self, [PotcarCorrection(i_s),
+                   GasCorrection(fp, correct_peroxide=correct_peroxide),
+                   UCorrection(fp, i_s, compat_type)])
 
 
+@cached_class
 class MITCompatibility(Compatibility):
     """
     This class implements the GGA/GGA+U mixing scheme, which allows mixing of
@@ -440,12 +416,76 @@ class MITCompatibility(Compatibility):
             equivalent GGA entries excluded. For example, Fe oxides should
             have a U value under the Advanced scheme. A GGA Fe oxide run
             will therefore be excluded under the scheme.
-        correct_peroxide: Specify whether peroxide/superoxide/ozonide 
-            corrections are to be applied or not. 
+        correct_peroxide: Specify whether peroxide/superoxide/ozonide
+            corrections are to be applied or not.
     """
 
     def __init__(self, compat_type="Advanced", correct_peroxide=True):
-        name = "MIT"
+        module_dir = os.path.dirname(os.path.abspath(__file__))
+        fp = os.path.join(module_dir, "MITCompatibility.yaml")
+        i_s = MITVaspInputSet()
         Compatibility.__init__(
-            self, [PotcarCorrection(name), GasCorrection(name, correct_peroxide=correct_peroxide),
-                   UCorrection(name, compat_type)])
+            self, [PotcarCorrection(i_s),
+                   GasCorrection(fp, correct_peroxide=correct_peroxide),
+                   UCorrection(fp, i_s, compat_type)])
+
+
+@cached_class
+class MITAqueousCompatibility(Compatibility):
+    """
+    This class implements the GGA/GGA+U mixing scheme, which allows mixing of
+    entries. Note that this should only be used for VASP calculations using the
+    MIT parameters (see pymatgen.io.vaspio_set MITVaspInputSet). Using
+    this compatibility scheme on runs with different parameters is not valid.
+
+    Args:
+        compat_type: Two options, GGA or Advanced.  GGA means all GGA+U
+            entries are excluded.  Advanced means mixing scheme is
+            implemented to make entries compatible with each other,
+            but entries which are supposed to be done in GGA+U will have the
+            equivalent GGA entries excluded. For example, Fe oxides should
+            have a U value under the Advanced scheme. A GGA Fe oxide run
+            will therefore be excluded under the scheme.
+        correct_peroxide: Specify whether peroxide/superoxide/ozonide
+            corrections are to be applied or not.
+    """
+
+    def __init__(self, compat_type="Advanced", correct_peroxide=True):
+        module_dir = os.path.dirname(os.path.abspath(__file__))
+        fp = os.path.join(module_dir, "MITCompatibility.yaml")
+        i_s = MITVaspInputSet()
+        Compatibility.__init__(
+            self, [PotcarCorrection(i_s),
+                   GasCorrection(fp, correct_peroxide=correct_peroxide),
+                   UCorrection(fp, i_s, compat_type), AqueousCorrection(fp)])
+
+
+@cached_class
+class MaterialsProjectAqueousCompatibility(Compatibility):
+    """
+    This class implements the GGA/GGA+U mixing scheme, which allows mixing of
+    entries. Note that this should only be used for VASP calculations using the
+    MaterialsProject parameters (see pymatgen.io.vaspio_set.MPVaspInputSet).
+    Using this compatibility scheme on runs with different parameters is not
+    valid.
+
+    Args:
+        compat_type: Two options, GGA or Advanced.  GGA means all GGA+U
+            entries are excluded.  Advanced means mixing scheme is
+            implemented to make entries compatible with each other,
+            but entries which are supposed to be done in GGA+U will have the
+            equivalent GGA entries excluded. For example, Fe oxides should
+            have a U value under the Advanced scheme. A GGA Fe oxide run
+            will therefore be excluded under the scheme.
+        correct_peroxide: Specify whether peroxide/superoxide/ozonide
+            corrections are to be applied or not.
+    """
+
+    def __init__(self, compat_type="Advanced", correct_peroxide=True):
+        module_dir = os.path.dirname(os.path.abspath(__file__))
+        fp = os.path.join(module_dir, "MPCompatibility.yaml")
+        i_s = MPVaspInputSet()
+        Compatibility.__init__(
+            self, [PotcarCorrection(i_s),
+                   GasCorrection(fp, correct_peroxide=correct_peroxide),
+                   UCorrection(fp, i_s, compat_type), AqueousCorrection(fp)])
