@@ -42,6 +42,8 @@ from pymatgen.electronic_structure.bandstructure import BandStructure, \
     BandStructureSymmLine, get_reconstructed_band_structure
 from pymatgen.core.lattice import Lattice
 from pymatgen.io.vaspio.vasp_input import Incar, Kpoints, Poscar
+from pymatgen.entries.computed_entries import \
+    ComputedEntry, ComputedStructureEntry
 
 logger = logging.getLogger(__name__)
 
@@ -193,7 +195,8 @@ class Vasprun(object):
                             "actual_kpoints_weights", "dos_energies",
                             "eigenvalues", "tdos", "idos", "pdos", "efermi",
                             "ionic_steps", "dos_has_errors",
-                            "projected_eigenvalues", "dielectric", "epsilon_static"]
+                            "projected_eigenvalues", "dielectric",
+                            "epsilon_static"]
 
     def __init__(self, filename, ionic_step_skip=None,
                  ionic_step_offset=0, parse_dos=True,
@@ -312,6 +315,41 @@ class Vasprun(object):
         """
         return True if self.parameters.get("ISPIN", 1) == 2 else False
 
+    def get_computed_entry(self, inc_structure=False, parameters=None,
+                           data=None):
+        """
+        Returns a ComputedStructureEntry from the vasprun.
+
+        Args:
+            inc_structure (bool): Set to True if you want
+                ComputedStructureEntries to be returned instead of
+                ComputedEntries.
+            parameters (list): Input parameters to include. It has to be one of
+                the properties supported by the Vasprun object. If
+                parameters == None, a default set of parameters that are
+                necessary for typical post-processing will be set.
+            data (list): Output data to include. Has to be one of the properties
+                supported by the Vasprun object.
+
+        Returns:
+            ComputedStructureEntry/ComputedEntry
+        """
+        param_names = {"is_hubbard", "hubbards", "potcar_symbols",
+                       "run_type"}
+        if parameters:
+            param_names.update(parameters)
+        params = {p: getattr(self, p) for p in param_names}
+        data = {p: getattr(self, p) for p in data} if data is not None else {}
+
+        if inc_structure:
+            return ComputedStructureEntry(self.final_structure,
+                                          self.final_energy, parameters=params,
+                                          data=data)
+        else:
+            return ComputedEntry(self.final_structure.composition,
+                                 self.final_energy, parameters=params,
+                                 data=data)
+
     def get_band_structure(self, kpoints_filename=None, efermi=None,
                            line_mode=False):
         """
@@ -350,7 +388,8 @@ class Vasprun(object):
         if not kpoints_filename:
             kpoints_filename = self.filename.replace('vasprun.xml', 'KPOINTS')
         if not os.path.exists(kpoints_filename) and line_mode is True:
-            raise VaspParserError('KPOINTS needed to obtain band structure along symmetry lines.')
+            raise VaspParserError('KPOINTS needed to obtain band structure '
+                                  'along symmetry lines.')
 
         if efermi is None:
             efermi = self.efermi
@@ -440,7 +479,8 @@ class Vasprun(object):
                     eigenvals = {Spin.up: up_eigen}
             else:
                 if '' in kpoint_file.labels:
-                    raise Exception("a band structure along symmetry lines requires a label for each kpoint. "
+                    raise Exception("A band structure along symmetry lines "
+                                    "requires a label for each kpoint. "
                                     "Check your KPOINTS file")
                 labels_dict = dict(zip(kpoint_file.labels, kpoint_file.kpts))
                 labels_dict.pop(None, None)
@@ -886,8 +926,8 @@ class VasprunHandler(xml.sax.handler.ContentHandler):
             self.stress.shape = (3, 3)
             self.read_positions = False
         elif name == "varray" and state["varray"] == "epsilon":
-            self.epsilon_static = np.array(map(float,
-                                        self.epsilonstr.getvalue().split()))
+            self.epsilon_static = np.array(
+                map(float, self.epsilonstr.getvalue().split()))
             self.epsilon_static.shape = (3, 3)
             self.read_epsilon_static = False
         elif name == "calculation":
@@ -1147,7 +1187,7 @@ class Outcar(object):
 
     One can then call a specific reader depending on the type of run being
     performed. These are currently: read_igpar(), read_lepsilon() and
-    read_lcalcpol().
+    read_lcalcpol(), read_core_state_eign().
 
     See the documentation of those methods for more documentation.
 
@@ -1483,6 +1523,40 @@ class Outcar(object):
         except:
             raise Exception("CLACLCPOL OUTCAR could not be parsed.")
 
+    def read_core_state_eigen(self):
+        """
+        Read the core state eigenenergies at each ionic step.
+
+        Returns:
+            A list of dict over the atom such as [{"AO":[core state eig]}].
+            The core state eigenenergie list for each AO is over all ionic
+            step.
+
+        Example:
+            The core state eigenenergie of the 2s AO of the 6th atom of the
+            structure at the last ionic step is [5]["2s"][-1]
+        """
+
+        Natom = len(self.charge)
+        CL = [dict() for i in range(Natom)]
+
+        foutcar = zopen(self.filename, "r")
+        line = foutcar.readline()
+        while line != "":
+            line = foutcar.readline()
+
+            if "the core state eigen" in line:
+                for iat in range(Natom):
+                    line = foutcar.readline()
+                    data = line.split()[1:]
+                    for i in range(0, len(data), 2):
+                        if CL[iat].has_key(data[i]):
+                            CL[iat][data[i]].append(float(data[i+1]))
+                        else:
+                            CL[iat][data[i]] = [float(data[i+1])]
+
+        return CL
+
     @property
     def to_dict(self):
         d = {"@module": self.__class__.__module__,
@@ -1673,9 +1747,22 @@ class VolumetricData(object):
 
         f = zopen(file_name, "w")
         p = Poscar(self.structure)
-        f.write(p.get_string(vasp4_compatible=vasp4_compatible) + "\n")
+
+        lines = p.comment + "\n"
+        lines += "   1.00000000000000\n"
+        latt = self.structure.lattice.matrix
+        lines += " %12.6f%12.6f%12.6f\n" % tuple(latt[0,:])
+        lines += " %12.6f%12.6f%12.6f\n" % tuple(latt[1,:])
+        lines += " %12.6f%12.6f%12.6f\n" % tuple(latt[2,:])
+        if not vasp4_compatible:
+            lines += "".join(["%5s" % s for s in p.site_symbols]) + "\n"
+        lines += "".join(["%6d" % x for x in p.natoms]) + "\n"
+        lines += "Direct\n"
+        for site in self.structure:
+            lines += "%10.6f%10.6f%10.6f\n" % tuple(site.frac_coords)
+        lines += "\n"
+        f.write(lines)
         a = self.dim
-        f.write("\n")
 
         def write_spin(data_type):
             lines = []
@@ -2014,8 +2101,18 @@ class Oszicar(object):
         ionic_steps = []
         ionic_pattern = re.compile("(\d+)\s+F=\s*([\d\-\.E\+]+)\s+"
                                    "E0=\s*([\d\-\.E\+]+)\s+"
-                                   "d\s*E\s*=\s*([\d\-\.E\+]+)\s+"
-                                   "mag=\s*([\d\-\.E\+]+)")
+                                   "d\s*E\s*=\s*([\d\-\.E\+]+)$")
+        ionic_mag_pattern = re.compile("(\d+)\s+F=\s*([\d\-\.E\+]+)\s+"
+                                       "E0=\s*([\d\-\.E\+]+)\s+"
+                                       "d\s*E\s*=\s*([\d\-\.E\+]+)\s+"
+                                       "mag=\s*([\d\-\.E\+]+)")
+        ionic_MD_pattern = re.compile("(\d+)\s+T=\s*([\d\-\.E\+]+)\s+"
+                                      "E=\s*([\d\-\.E\+]+)\s+"
+                                      "F=\s*([\d\-\.E\+]+)\s+"
+                                      "E0=\s*([\d\-\.E\+]+)\s+"
+                                      "EK=\s*([\d\-\.E\+]+)\s+"
+                                      "SP=\s*([\d\-\.E\+]+)\s+"
+                                      "SK=\s*([\d\-\.E\+]+)")
         electronic_pattern = re.compile("\s*\w+\s*:(.*)")
 
         def smart_convert(header, num):
@@ -2043,10 +2140,24 @@ class Oszicar(object):
                         electronic_steps[-1].append(data)
                 elif ionic_pattern.match(line.strip()):
                     m = ionic_pattern.match(line.strip())
+                    ionic_steps.append({"F": float(m.group(2)),
+                                        "E0": float(m.group(3)),
+                                        "dE": float(m.group(4))})
+                elif ionic_mag_pattern.match(line.strip()):
+                    m = ionic_mag_pattern.match(line.strip())
                     ionic_steps.append({"F": float(m.group(2)),
                                         "E0": float(m.group(3)),
                                         "dE": float(m.group(4)),
                                         "mag": float(m.group(5))})
+                elif ionic_MD_pattern.match(line.strip()):
+                    m = ionic_MD_pattern.match(line.strip())
+                    ionic_steps.append({"T": float(m.group(2)),
+                                        "E": float(m.group(3)),
+                                        "F": float(m.group(4)),
+                                        "E0": float(m.group(5)),
+                                        "EK": float(m.group(6)),
+                                        "SP": float(m.group(7)),
+                                        "SK": float(m.group(8))})
                 elif re.match("^\s*N\s+E\s*", line):
                     header = line.strip().replace("d eps", "deps").split()
         self.electronic_steps = electronic_steps
@@ -2141,6 +2252,46 @@ def get_band_structure_from_vasp_multiple_branches(dir_name, efermi=None,
             return None
 
 
+class Xdatcar(object):
+    """
+    Class representing an XDATCAR file. Only tested with VASP 5.x files.
+
+    .. attribute:: structures
+
+        List of structures parsed from XDATCAR.
+    """
+
+    def __init__(self, filename):
+        """
+        Init a Xdatcar.
+
+        Args:
+            filename (str): Filename of XDATCAR file.
+        """
+        preamble = None
+        coords_str = []
+        structures = []
+        preamble_done = False
+        with zopen(filename) as f:
+            for l in f:
+                l = l.strip()
+                if preamble is None:
+                    preamble = [l]
+                elif not preamble_done:
+                    if l == "":
+                        preamble_done = True
+                    else:
+                        preamble.append(l)
+                elif l == "":
+                    p = Poscar.from_string("\n".join(preamble +
+                                                     ["Direct"] + coords_str))
+                    structures.append(p.structure)
+                    coords_str = []
+                else:
+                    coords_str.append(l)
+        self.structures = structures
+
+
 def get_adjusted_fermi_level(efermi, cbm, band_structure):
     """
     When running a band structure computations the fermi level needs to be
