@@ -6,8 +6,8 @@ API to enable the creation of data structures and pymatgen objects using
 Materials Project data.
 
 To make use of the Materials API, you need to be a registered user of the
-Materials Project, and obtain an API key by going to your profile at
-https://www.materialsproject.org/profile.
+Materials Project, and obtain an API key by going to your dashboard at
+https://www.materialsproject.org/dashboard.
 """
 
 from __future__ import division
@@ -74,8 +74,17 @@ class MPRester(object):
                             "is_hubbard", "elements", "nelements",
                             "e_above_hull", "hubbards", "is_compatible",
                             "spacegroup", "task_ids", "band_gap", "density",
-                            "icsd_id", "cif", "total_magnetization",
-                            "material_id")
+                            "icsd_id", "icsd_ids", "cif", "total_magnetization",
+                            "material_id", "oxide_type")
+
+    supported_task_properties = ("energy", "energy_per_atom", "volume",
+                                 "formation_energy_per_atom", "nsites",
+                                 "unit_cell_formula", "pretty_formula",
+                                 "is_hubbard",
+                                 "elements", "nelements", "e_above_hull",
+                                 "hubbards",
+                                 "is_compatible", "spacegroup",
+                                 "band_gap", "density", "icsd_id", "cif")
 
     def __init__(self, api_key=None, host="www.materialsproject.org"):
         if api_key is not None:
@@ -125,7 +134,7 @@ class MPRester(object):
             data_type (str): Type of data to return. Currently can either be
                 "vasp" or "exp".
             prop (str): Property to be obtained. Should be one of the
-                MPRester.supported_properties. Leave as empty string for a
+                MPRester.supported_task_properties. Leave as empty string for a
                 general list of useful properties.
         """
         if prop:
@@ -201,7 +210,6 @@ class MPRester(object):
                 response, "content") else str(ex)
             raise MPRestError(msg)
 
-
     def get_structures(self, chemsys_formula_id, final=True):
         """
         Get a list of Structures corresponding to a chemical system, formula,
