@@ -90,12 +90,17 @@ class SuperTransformation(AbstractTransformation):
     object.
 
     Args:
-        transformations: List of transformations to apply to a structure.
-            One transformation is applied to each output structure.
+        transformations ([transformations]): List of transformations to apply
+            to a structure. One transformation is applied to each output
+            structure.
+        nstructures_per_trans (int): If the transformations are one-to-many and,
+            nstructures_per_trans structures from each transformation are
+            added to the full list. Defaults to 1, i.e., only best structure.
     """
 
-    def __init__(self, transformations):
+    def __init__(self, transformations, nstructures_per_trans=1):
         self._transformations = transformations
+        self.nstructures_per_trans = nstructures_per_trans
 
     def apply_transformation(self, structure, return_ranked_list=False):
         if not return_ranked_list:
@@ -103,9 +108,16 @@ class SuperTransformation(AbstractTransformation):
                              " output. Must use return_ranked_list")
         structures = []
         for t in self._transformations:
-            structures.append(
-                {"transformation": t,
-                 "structure": t.apply_transformation(structure)})
+            if t.is_one_to_many:
+                for d in t.apply_transformation(
+                        structure,
+                        return_ranked_list=self.nstructures_per_trans):
+                    d["transformation"] = t
+                    structures.append(d)
+            else:
+                structures.append(
+                    {"transformation": t,
+                     "structure": t.apply_transformation(structure)})
         return structures
 
     def __str__(self):
@@ -126,7 +138,9 @@ class SuperTransformation(AbstractTransformation):
     @property
     def to_dict(self):
         return {"name": self.__class__.__name__, "version": __version__,
-                "init_args": {"transformations": self._transformations},
+                "init_args": {
+                    "transformations": self._transformations,
+                    "nstructures_per_trans": self.nstructures_per_trans},
                 "@module": self.__class__.__module__,
                 "@class": self.__class__.__name__}
 
@@ -496,11 +510,18 @@ class MagOrderingTransformation(AbstractTransformation):
         for sp, spin in self.mag_species_spin.items():
             sp = get_el_sp(sp)
             oxi_state = getattr(sp, "oxi_state", 0)
-            up = Specie(sp.symbol, oxi_state, {"spin": abs(spin)})
-            down = Specie(sp.symbol, oxi_state, {"spin": -abs(spin)})
-            mods.replace_species(
-                {sp: Composition({up: self.order_parameter,
-                                  down: 1 - self.order_parameter})})
+            if spin:
+                up = Specie(sp.symbol, oxi_state, {"spin": abs(spin)})
+                down = Specie(sp.symbol, oxi_state, {"spin": -abs(spin)})
+                mods.replace_species(
+                    {sp: Composition({up: self.order_parameter,
+                                      down: 1 - self.order_parameter})})
+            else:
+                mods.replace_species(
+                    {sp: Specie(sp.symbol, oxi_state, {"spin": spin})})
+
+        if mods.is_ordered:
+            return [mods] if return_ranked_list > 1 else mods
 
         enum_args = self.enum_kwargs
 
@@ -528,8 +549,8 @@ class MagOrderingTransformation(AbstractTransformation):
         except ValueError:
             num_to_return = 1
 
-        if num_to_return == 1:
-            return alls[0]["structure"]
+        if num_to_return == 1 or not return_ranked_list:
+            return alls[0]["structure"] if num_to_return else alls
 
         m = StructureMatcher(comparator=SpinComparator())
 
