@@ -26,11 +26,13 @@ import multiprocessing
 
 save_file = "gau_data.gz"
 
+
 def get_energies(rootdir, reanalyze, verbose, pretty):
     if verbose:
         FORMAT = "%(relativeCreated)d msecs : %(message)s"
         logging.basicConfig(level=logging.INFO, format=FORMAT)
-    drone = GaussianToComputedEntryDrone(inc_structure=True, parameters=['filename'])
+    drone = GaussianToComputedEntryDrone(inc_structure=True,
+                                         parameters=['filename'])
     ncpus = multiprocessing.cpu_count()
     logging.info('Detected {} cpus'.format(ncpus))
     queen = BorgQueen(drone, number_of_drones=ncpus)
@@ -40,11 +42,11 @@ def get_energies(rootdir, reanalyze, verbose, pretty):
         queen.load_data(save_file)
     else:
         queen.parallel_assimilate(rootdir)
-        msg = 'Analysis results saved to {} for faster subsequent loading.'.format(save_file)
+        msg = 'Results saved to {} for faster reloading.'.format(save_file)
         queen.save_data(save_file)
 
     entries = queen.get_data()
-    entries = sorted(entries, key=lambda x:x.parameters['filename'])
+    entries = sorted(entries, key=lambda x: x.parameters['filename'])
     all_data = [(e.parameters['filename'].replace("./", ""),
                  re.sub("\s+", "", e.composition.formula),
                  "{}".format(e.parameters['charge']),
@@ -64,19 +66,31 @@ def get_energies(rootdir, reanalyze, verbose, pretty):
     print msg
 
 
+desc = '''
+Convenient Gaussian run analyzer which can recursively go into a directory
+to search results.
+Author: Shyue Ping Ong
+Version: 1.0
+Last updated: Jul 6 2012'''
+
 if __name__ == "__main__":
-    parser = argparse.ArgumentParser(description='''Convenient Gaussian run analyzer which can recursively go into a directory to search results.
-    Author: Shyue Ping Ong
-    Version: 1.0
-    Last updated: Jul 6 2012''')
+    parser = argparse.ArgumentParser(description=desc)
     parser.add_argument('directories', metavar='dir', default='.', type=str,
                         nargs='*', help='directory to process')
-    parser.add_argument('-v', '--verbose', dest="verbose", action='store_const',
-                        const=True, help='verbose mode. Provides detailed output on progress.')
+    parser.add_argument('-v', '--verbose', dest="verbose",
+                        action='store_const', const=True,
+                        help='verbose mode. Provides detailed output ' +
+                        'on progress.')
     parser.add_argument('-p', '--pretty', dest="pretty", action='store_const',
-                        const=True, help='pretty mode. Uses prettytable to format output. Must have prettytable module installed.')
-    parser.add_argument('-f', '--force', dest="reanalyze", action='store_const',
-                        const=True, help='force reanalysis. Typically, gaussian_analyzer will just reuse a gaussian_analyzer_data.gz if present. This forces the analyzer to reanalyze.')
+                        const=True,
+                        help='pretty mode. Uses prettytable to format ' +
+                        'output. Must have prettytable module installed.')
+    parser.add_argument('-f', '--force', dest="reanalyze",
+                        action='store_const',
+                        const=True,
+                        help='force reanalysis. Typically, gaussian_analyzer' +
+                        ' will just reuse a gaussian_analyzer_data.gz if ' +
+                        'present. This forces the analyzer to reanalyze.')
 
     args = parser.parse_args()
     for d in args.directories:
